@@ -1,11 +1,12 @@
-from typing import Optional
+from typing import Optional, Union
 
-from ._logger import logger
-from ._meta import _load_meta
+from ._logger import colors, logger
+from ._meta import meta
 from .dev._check_last_cell import check_last_cell
 from .dev._consecutiveness import check_consecutiveness
 from .dev._jupyter_lab_commands import _save_notebook
 from .dev._notebook import read_notebook
+from .dev._set_version import set_version
 
 
 def publish(
@@ -13,17 +14,17 @@ def publish(
     version: Optional[str] = None,
     i_confirm_i_saved: bool = False,
     **kwargs,
-):
-    """Publish your notebook before sharing it to ensure it's reproducible.
+) -> Union[None, str]:
+    """Publish your notebook before sharing it.
 
-    This function should be called in the last code cell of the notebook!
+    1. Sets version.
+    2. Stores pypackages.
+    3. Checks consecutiveness, i.e., whether notebook cells were executed consecutively.
+    4. Checks that the notebook has a title.
 
-    1. Checks that the notebook has a title.
-    2. Sets the version.
-    3. Stores dependencies.
-    4. Checks consecutiveness, i.e., whether notebook cells were executed consecutively.
+    This function has to be called in the last code cell of the notebook.
 
-    Returns the consecutiveness check result.
+    Returns `None` upon success and an error code otherwise.
 
     Args:
         version: If `None`, bumps the version from "draft" to "1", from "1" to "2", etc.
@@ -31,7 +32,6 @@ def publish(
         i_confirm_i_saved: Only relevant outside Jupyter Lab as a safeguard against
             losing the editor buffer content because of accidentally publishing.
     """
-    meta = _load_meta()
     if "calling_statement" in kwargs:
         calling_statement = kwargs["calling_statement"]
     else:
@@ -39,12 +39,13 @@ def publish(
 
     notebook_title = meta.live.title
     title_error = (
-        "Error: No title! Please update & save your notebook so that it has a"
-        " markdown cell with the title: # My title"
+        f"No title! Update & {colors.bold('save')} your notebook with a title '# My"
+        " title' in the first cell."
     )
 
     if notebook_title is None:
-        raise RuntimeError(title_error)
+        logger.error(title_error)
+        return "no-title"
 
     if meta._env == "lab":
         _save_notebook()
@@ -62,27 +63,25 @@ def publish(
                 "You can avoid the need for manually saving in Jupyter Lab, which auto-saves the buffer during publish."  # noqa
             )
 
-    nb = read_notebook(meta._filepath)
+    nb = read_notebook(meta._filepath)  # type: ignore
     if not check_last_cell(nb, calling_statement):
         raise RuntimeError("Can only publish from the last code cell of the notebook.")
-    check_consecutiveness(nb)
 
-    if version is not None:
-        meta.store.version = version
-    else:
-        try:
-            if meta.store.version == "draft":
-                version = "1"
-            else:
-                version = str(int(meta.store.version) + 1)  # bump version by 1
-            meta.store.version = version
-        except ValueError:
-            raise ValueError(
-                "The nbproject version cannot be cast to integer. Please pass a version"
-                " string."
-            )
+    if not check_consecutiveness(nb):
+        if meta._env == "test":
+            decide = "y"
+        else:
+            decide = input("   Do you still want to proceed with publishing? (y/n) ")
 
-    meta.store.dependency = meta.live.dependency
-    logger.info(f"Bumped notebook version to {version} & wrote dependencies.")
+        if decide != "y":
+            logger.warning("Aborted!")
+            return "aborted"
 
-    meta.store.write()
+    meta.store.version = set_version(version)
+    meta.store.pypackage = meta.live.pypackage
+    logger.info(
+        f"Set notebook version to {colors.bold(meta.store.version)} & wrote pypackages."
+    )
+
+    meta.store.write(calling_statement=calling_statement)
+    return None
