@@ -3,6 +3,6 @@ def public_fields(obj):
     for key in dir(obj):
         if key[0] != "_":
             value = getattr(obj, key)
-            if not callable(value):
+            if not callable(value) and value is not None:
                 vars_props_dict[key] = value
     return vars_props_dict
